==> 1.0.0.tar.gz: lib/src/main/MixinApplicationClass.dart <==
import '../ParserType.dart';
import '../ParserExceptions.dart';
import '../lexer/Lexer.dart';
import '../core/Identifier.dart';
import '../lists/TypeParameters.dart';
import '../sub_types/Types.dart';
import 'Interfaces.dart';
import 'Mixins.dart';

/*
<mixinApplicationClass> ::=
<identifier> <typeParameters>? '=' <mixinApplication> ';'

See https://dart.dev/guides/language/specifications/DartLangSpec-v2.2.pdf
Page 57
*/
class MixinApplicationClass extends ParserType {
  Identifier identifier;
  TypeParameters typeParameters;
  MixinApplication mixinApplication;

  MixinApplicationClass(Lexer lexer) {
    identifier = Identifier(lexer);

    int snapShot = lexer.currentIndex;
    try {
      typeParameters = TypeParameters(lexer);
    }
    on WrongTokenType {
      lexer.setPos(snapShot);
    }

    checkType(lexer, TType.EQUALS);
    lexer.advance();

    mixinApplication = MixinApplication(lexer);

    checkType(lexer, TType.SEMICOLON);
    lexer.advance();
  }

  String toString() {
    return '$identifier' + (typeParameters != null ? ' $typeParameters' : '') + ' = $mixinApplication;';
  }

}

/* <mixinApplication> ::= <typeNotVoid> <mixins> <interfaces>? */
class MixinApplication extends ParserType {
  TypeNotVoid typeNotVoid;
  Mixins mixins;
  Interfaces interfaces;

  MixinApplication(Lexer lexer) {
    typeNotVoid = TypeNotVoid(lexer);
    mixins = Mixins(lexer);

    int snapShot = lexer.currentIndex;
    try {
      interfaces = Interfaces(lexer);
    }
    on WrongTokenType {
      lexer.setPos(snapShot);
    }
  }

  String toString() {
    return '$typeNotVoid $mixins' +
            (interfaces != null ? ' $interfaces' : '');
  }

}

==> 1.1.1.tar.gz: lib/src/main/MixinApplicationClass.dart <==
import '../ParserType.dart';
import '../ParserExceptions.dart';
import '../lexer/Lexer.dart';
import '../core/Identifier.dart';
import '../lists/TypeParameters.dart';
import '../sub_types/Types.dart';
import 'Interfaces.dart';
import 'Mixins.dart';

/// <mixinApplicationClass> ::=
/// <identifier> <typeParameters>? '=' <mixinApplication> ';'
///
/// See https://dart.dev/guides/language/specifications/DartLangSpec-v2.2.pdf
/// Page 57
class MixinApplicationClass extends ParserType {
  Identifier identifier;
  TypeParameters typeParameters;
  MixinApplication mixinApplication;

  MixinApplicationClass(Lexer lexer) {
    identifier = Identifier(lexer);

    int snapShot = lexer.currentIndex;
    try {
      typeParameters = TypeParameters(lexer);
    } on WrongTokenType {
      lexer.setPos(snapShot);
    }

    checkType(lexer, TType.EQUALS);
    lexer.advance();

    mixinApplication = MixinApplication(lexer);

    checkType(lexer, TType.SEMICOLON);
    lexer.advance();
  }

  String toString() {
    return '$identifier' +
        (typeParameters != null ? ' $typeParameters' : '') +
        ' = $mixinApplication;';
  }
}

/// <mixinApplication> ::= <typeNotVoid> <mixins> <interfaces>?
class MixinApplication extends ParserType {
  TypeNotVoid typeNotVoid;
  Mixins mixins;
  Interfaces interfaces;

  MixinApplication(Lexer lexer) {
    typeNotVoid = TypeNotVoid(lexer);
    mixins = Mixins(lexer);

    int snapShot = lexer.currentIndex;
    try {
      interfaces = Interfaces(lexer);
    } on WrongTokenType {
      lexer.setPos(snapShot);
    }
  }

  String toString() {
    return '$typeNotVoid $mixins' + (interfaces != null ? ' $interfaces' : '');
  }
}
